Base schema: "http://purl.allotrope.org/json-schemas/adm/spectrophotometry/REC/2024/06/spectrophotometry.schema"

Changes:

* Addition of fluorescence point measurment detection
  * Reasoning: proposed extension to the spectrophotometry model to support fluorescence measurement
  * Proposal: Request extension be reflected in the Allotrope schema
* Addition of luminescence point measurment detection
  * Reasoning: proposed extension to the spectrophotometry model to support luminescence measurement
  * Proposal: Request extension be reflected in the Allotrope schema
* Addition of absorption spectrum measurment detection
  * Reasoning: proposed extension to the spectrophotometry model to support absorption spectrum measurement
  * Proposal: Request extension be reflected in the Allotrope schema
* Addition of fluorescence emission spectrum measurment detection
  * Reasoning: proposed extension to the spectrophotometry model to support fluorescence emission spectrum measurement
  * Proposal: Request extension be reflected in the Allotrope schema
* Addition of allotrope cube.schema
  * Reasoning: require validation of tDataCube objects based on dimension/measure concepts and units
* Add GramPerLiter, MilligramPerLiter, PartsPerBillion, PartsPerMillion units to dervived mass concentration available units
  * Reasoning: proposed extension to the spectrophotometry model to support additional derived mass concentration units obtained
  * Proposal: Request extension be reflected in the Allotrope schema
